package de.ciluvien.mensen.ui.components.core

import androidx.compose.material3.CenterAlignedTopAppBar
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.material3.TopAppBarDefaults
import androidx.compose.material3.TopAppBarScrollBehavior
import androidx.compose.runtime.Composable
import androidx.compose.ui.graphics.vector.ImageVector

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun CustomTopAppBar(
    title: String,
    scrollBehavior: TopAppBarScrollBehavior = TopAppBarDefaults.pinnedScrollBehavior(),
    leftIcon: CustomTextIcon? = null,
    rightIcon: CustomTextIcon? = null
) {
    CenterAlignedTopAppBar(
        title = {
            Text(
                text = title,
                style = MaterialTheme.typography.headlineMedium
            )
        },
        navigationIcon = {
            if (leftIcon != null) {
                IconButton(onClick = leftIcon.onClick) {
                    Icon(
                        imageVector = leftIcon.icon,
                        contentDescription = leftIcon.description
                    )
                }
            }
        },
        actions = {
            if (rightIcon != null) {
                IconButton(onClick = rightIcon.onClick) {
                    Icon(
                        imageVector = rightIcon.icon,
                        contentDescription = rightIcon.description
                    )
                }
            }
        },
        scrollBehavior = scrollBehavior
    )
}

data class CustomTextIcon(
    val onClick: () -> Unit,
    val icon: ImageVector,
    val description: String
)
