package de.ciluvien.mensen.ui.screens

import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.padding
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.outlined.ArrowBack
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Scaffold
import androidx.compose.material3.TopAppBarDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.vector.ImageVector
import androidx.compose.ui.input.nestedscroll.nestedScroll
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.vectorResource
import androidx.lifecycle.viewmodel.compose.viewModel
import de.ciluvien.mensen.MensenApp
import de.ciluvien.mensen.R
import de.ciluvien.mensen.ui.components.MealDetails
import de.ciluvien.mensen.ui.components.core.CustomTextIcon
import de.ciluvien.mensen.ui.components.core.CustomTopAppBar
import de.ciluvien.mensen.ui.viewModelFactory
import de.ciluvien.mensen.ui.viewmodels.MealDetailsViewModel
import java.time.LocalDate

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun MealDetailsScreen(
    onNavigateBack: () -> Unit,
    onNavigateImage: (String) -> Unit,
    canteenName: String,
    mealId: Int,
    date: LocalDate
) {
    val context = LocalContext.current
    val viewModel = viewModel<MealDetailsViewModel>(
        factory = viewModelFactory {
            MealDetailsViewModel(MensenApp.appModule)
        }
    )
    LaunchedEffect(key1 = true) {
        viewModel.getMeal(mealId, date)
        viewModel.getBookmarkState(date)
    }

    val scrollBehavior = TopAppBarDefaults.pinnedScrollBehavior()
    Scaffold(
        modifier = Modifier.nestedScroll(scrollBehavior.nestedScrollConnection),
        topBar = {
            val bookmarkIcon = if (viewModel.bookmarkState.value) {
                CustomTextIcon(
                    onClick = { viewModel.setBookmarkState(false, date) },
                    icon = ImageVector.vectorResource(R.drawable.baseline_bookmark_24),
                    description = context.resources.getText(R.string.meal_remove_bookmark).toString()
                )
            } else {
                CustomTextIcon(
                    onClick = { viewModel.setBookmarkState(true, date) },
                    icon = ImageVector.vectorResource(R.drawable.baseline_bookmark_border_24),
                    description = context.resources.getText(R.string.meal_set_bookmark).toString()
                )
            }

            CustomTopAppBar(
                title = canteenName,
                scrollBehavior = scrollBehavior,
                leftIcon = CustomTextIcon(
                    onClick = onNavigateBack,
                    icon = Icons.AutoMirrored.Outlined.ArrowBack,
                    description = context.resources.getText(R.string.meal_back).toString()
                ),
                rightIcon = bookmarkIcon
            )
        }
    ) {padding ->
        Box(modifier = Modifier.padding(padding)) {
            MealDetails(
                meal = viewModel.meal.value,
                scrollBehavior = scrollBehavior,
                onNavigateImage = onNavigateImage
            )
        }
    }
}